@@ -1,6 +1,6 @@
 package Puzzle::Exception;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use base 'Class::Container';
 use File::Spec;
@@ -13,8 +13,6 @@ sub raise {
 	my $mason		= $self->container->_mason;
 
 	# add original component yaml structures to add errors
-
-	#my $base_root   = $mason->interp->comp_root;
 	my $comp_path	= $mason->current_comp->source_file;
 
 	my @dots = split(/\./,$comp_path);
@@ -32,13 +30,17 @@ sub raise {
 	}
 
 
-
-	my $error_path = $self->container->cfg->exception_file;
-
 	$self->container->args->set(errorcode => $error_code);
-	print $tmpl->html(undef,$error_path);
+	$self->print;
 	# usefull to return your function with 0 if errors
 	return 0;
 }
 
+sub print {
+	my $self	= shift;
+	my $error_path = $self->container->cfg->exception_file;
+	print $self->container->tmpl->html(undef,$error_path);
+
+}
+
 1;
