@@ -1,14 +1,13 @@
 package Puzzle::Template::DBIxClassConverter;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use base 'Class::Container';
 
 sub resultset {
 	my $self	= shift;
 	my $rs		= shift;
-
-	my $tblName	= $rs->result_source->name;
+	my $key		= shift || $rs->result_source->name;
 
 	my @ret;
 
@@ -16,7 +15,7 @@ sub resultset {
 		push @ret,$self->row($rec);
 	}
 
-	return {$tblName => \@ret};
+	return {$key => \@ret};
 }
 
 sub row {
@@ -27,6 +26,17 @@ sub row {
 
 	my %ret		= $rs->get_columns;
 	$ret{"$tblName.$_"} = $ret{$_} foreach(keys %ret);
+	foreach (keys %{$rs->result_source->_relationships}) {
+		my $rrow = $rs->$_;
+		if (ref($rrow) eq 'DBIx::Class::ResultSet') {
+			if ($rrow->count == 1) {
+				my $single_row = $rrow->next;
+				%ret = (%ret,%{$self->row($single_row)});
+			} else {
+				%ret = (%ret,%{$self->resultset($rrow)});
+			}
+		}
+	}
 
 	return \%ret;
 }
